netapp_ontap.models.svm_ldap API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.svm_ldap`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class SvmLdapSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the SvmLdap object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `ad_domain: str GET POST PATCH`

    This parameter specifies the name of the Active Directory domain used to discover LDAP servers for use by this client. This is mutually exclusive with `servers` during POST.

  `base_dn: str GET POST PATCH`

    Specifies the default base DN for all searches.

  `bind_dn: str GET POST PATCH`

    Specifies the user that binds to the LDAP servers. SVM API supports anonymous binding. For Simple and SASL LDAP binding, use the LDAP API endpoint.

  `enabled: bool GET POST PATCH`

    Enable LDAP? Setting to true creates a configuration if not already created.

  `restrict_discovery_to_site: bool GET POST PATCH`

    Specifies whether or not LDAP server discovery is restricted to site-scope.

  `servers: List[str] GET POST PATCH`

    The servers field of the svm_ldap.